References — turbo-turtle 1.2.9 documentation

Skip to main content
`Ctrl`+`K`

# References

[1]

Dassault Systemés Simulia Corporation. Abaqus 2023. 2023. Providence, RI, USA.

[2]

National Technology and Engineering Solutions of Sandia, LLC. Cubit. 2022. Albuquerque, New Mexico, USA. URL: https://cubit.sandia.gov/ (visited on 2022-08-05).

[3]

Python Software Foundation. Python documentation. 2024. Beaverton, Oregon, USA. URL: https://docs.python.org/3/ (visited on 2024-03-04).

[4]

Anaconda, Inc. Conda. 2022. Austin, Texas, USA. URL: https://docs.conda.io/projects/conda/en/latest/index.html (visited on 2022-08-05).

[5]

Anaconda, Inc. Getting started with conda. 2022. Austin, Texas, USA. URL: https://docs.conda.io/projects/conda/en/latest/user-guide/getting-started.html (visited on 2022-08-05).

[6]

The SCons Development Team. SCons. 2022. URL: https://scons.org/ (visited on 2022-08-05).

[7]

The SCons Development Team. SCons 4.4.0: User Guide. The SCons Foundation, 4.4.0 edition, 2021.